@@ -43,7 +43,7 @@ using System.Diagnostics;
 using Mono.Addins;
 
 using MonoDevelop.Core;
-using MonoDevelop.Core.Gui;
+using MonoDevelop.Ide;
 using MonoDevelop.Core.Execution;
 using MonoDevelop.Core.ProgressMonitoring;
 using MonoDevelop.Projects;
@@ -384,8 +384,16 @@ namespace MonoDevelop.ValaBinding
 				packages = value;
 				packages.Project = this;
 				ProjectInformation pi = ProjectInformationManager.Instance.Get (this);
+				ValaProjectConfiguration configuration = (ValaProjectConfiguration)DefaultConfiguration;
+				
 				foreach(ProjectPackage p in packages) {
-					if (!p.IsProject){ pi.AddPackage (p.Name); }
+					if (p.IsProject) {
+						string file = Path.GetFullPath (Path.Combine (configuration.OutputDirectory, p.File));
+						LoggingService.LogDebug ("Adding {0} for project package {1}", file, p.Name);
+						pi.AddFile (file);
+					} else {
+						pi.AddPackage (p.Name);
+					}
 				}
 			}
 		}
@@ -456,7 +464,7 @@ namespace MonoDevelop.ValaBinding
 					string targetDirectory =
 						(/*IsHeaderFile (f.Name) ? TargetDirectory.Include :*/ TargetDirectory.ProgramFiles);
 					
-					deployFiles.Add (new DeployFile (this, f.FilePath, f.RelativePath, targetDirectory));
+					deployFiles.Add (new DeployFile (this, f.FilePath, f.ProjectVirtualPath, targetDirectory));
 				}
 			}
 			
